pub struct WireU32(/* private fields */);Expand description
32-bit unsigned little-endian wire integer.
Implementations
Sourceimpl WireU32
impl WireU32
Sourcepub fn checked_add_assign(&mut self, rhs: u32) -> Result<(), ProgramError>
pub fn checked_add_assign(&mut self, rhs: u32) -> Result<(), ProgramError>
Checked addition in native form, written back on success.
Sourcepub fn add_assign_checked(&mut self, rhs: u32) -> Result<(), ProgramError>
pub fn add_assign_checked(&mut self, rhs: u32) -> Result<(), ProgramError>
Alias for Self::checked_add_assign.
Sourcepub fn checked_sub_assign(&mut self, rhs: u32) -> Result<(), ProgramError>
pub fn checked_sub_assign(&mut self, rhs: u32) -> Result<(), ProgramError>
Checked subtraction in native form, written back on success.
Sourcepub fn sub_assign_checked(&mut self, rhs: u32) -> Result<(), ProgramError>
pub fn sub_assign_checked(&mut self, rhs: u32) -> Result<(), ProgramError>
Alias for Self::checked_sub_assign.
Sourcepub fn checked_mul_assign(&mut self, rhs: u32) -> Result<(), ProgramError>
pub fn checked_mul_assign(&mut self, rhs: u32) -> Result<(), ProgramError>
Checked multiplication in native form, written back on success.
Sourcepub fn mul_assign_checked(&mut self, rhs: u32) -> Result<(), ProgramError>
pub fn mul_assign_checked(&mut self, rhs: u32) -> Result<(), ProgramError>
Alias for Self::checked_mul_assign.
Sourcepub fn as_bytes_mut(&mut self) -> &mut [u8; 4]
pub fn as_bytes_mut(&mut self) -> &mut [u8; 4]
Raw byte access (mutable).