VerifiedAccountMut

Struct VerifiedAccountMut 

pub struct VerifiedAccountMut<'a, T: Pod + FixedLayout> { /* private fields */ }
Mutable verified account – proof that validation passed, with write access.

Implementations

Source

impl<'a, T: Pod + FixedLayout> VerifiedAccountMut<'a, T>

pub fn new(data: &'a mut [u8]) -> Result<Self, ProgramError>

Construct from pre-validated mutable data.

pub fn from_ref_mut(data: RefMut<'a, [u8]>) -> Result<Self, ProgramError>

Construct from a Hopper mutable borrow guard.

pub fn get(&self) -> &T

Get an immutable reference to the overlay.

The returned reference is bounded by &self; it cannot outlive this VerifiedAccountMut, which owns the mutable borrow guard or validated raw mutable slice.

pub fn get_mut(&mut self) -> &mut T

Get a mutable reference to the overlay.

The returned reference is bounded by &mut self, so there can be only one mutable overlay at a time and it cannot outlive the wrapper that owns the underlying account borrow.

pub fn with<U, F>(&self, f: F) -> U
where F: FnOnce(&T) -> U,

Run a closure with the verified whole-layout overlay.

pub fn with_mut<U, F>(&mut self, f: F) -> U
where F: FnOnce(&mut T) -> U,

Run a closure with the verified mutable whole-layout overlay.

pub fn data(&self) -> &[u8]

Raw data (immutable).

pub fn data_mut(&mut self) -> &mut [u8]

Raw data (mutable).

pub fn map<U, F>(&self, f: F) -> U
where F: FnOnce(&T) -> U,

Project a field from the verified overlay (immutable).

pub fn map_mut<U, F>(&mut self, f: F) -> U
where F: FnOnce(&mut T) -> U,

Project a field for mutation.

let mut vault = Vault::load_mut(account, program_id)?;
vault.map_mut(|v| {
    v.balance = WireU64::new(100);
});
pub fn overlay_at<U: Pod + FixedLayout>( &self, offset: usize, ) -> Result<&U, ProgramError>

Overlay a second Pod type at a given offset (immutable).

pub fn overlay_at_mut<U: Pod + FixedLayout>( &mut self, offset: usize, ) -> Result<&mut U, ProgramError>

Overlay a second Pod type at a given offset (mutable).