pub fn check_no_subsequent_invocation(
sysvar_data: &[u8],
our_program: &Address,
) -> ProgramResultExpand description
Ensure our program is not invoked after the current instruction.
Prevents post-execution re-entrancy patterns.
pub fn check_no_subsequent_invocation(
sysvar_data: &[u8],
our_program: &Address,
) -> ProgramResultEnsure our program is not invoked after the current instruction.
Prevents post-execution re-entrancy patterns.