pub struct FrameAccountMut<'a> { /* private fields */ }Expand description
Mutable account view within a Frame.
When this is dropped, the mutable borrow tracking bit is cleared, allowing the account to be re-borrowed.
Implementations
Sourceimpl<'a> FrameAccountMut<'a>
impl<'a> FrameAccountMut<'a>
Sourcepub fn view(&self) -> &AccountView
pub fn view(&self) -> &AccountView
The underlying AccountView.