InvariantSet

Struct InvariantSet 

pub struct InvariantSet { /* private fields */ }
Batch invariant checker.

Collects multiple invariant results and reports the first failure. All invariants are checked even after a failure (useful for diagnostics).

Implementations

Source

impl InvariantSet

pub const fn new() -> Self

Create a new empty invariant set.

pub fn check(&mut self, condition: bool, code: u32)

Add an invariant check.

pub fn check_fn<F: FnOnce() -> bool>(&mut self, f: F, code: u32)

Add an invariant check with lazy evaluation.

pub fn checked_count(&self) -> u16

Get the number of invariants checked.

pub fn passed_count(&self) -> u16

Get the number of invariants that passed.

pub fn all_passed(&self) -> bool

Did all invariants pass?

pub fn finalize(self) -> Result<(), ProgramError>

Finalize: return Ok if all passed, or the first failure code.