pub struct AccountConstraint { /* private fields */ }Expand description
A builder for constructing validation constraints on a single account.
ⓘ
AccountConstraint::on(0)
.signer()
.writable()
.owned_by_program()
.validate(&ctx)?;Implementations
Sourceimpl AccountConstraint
impl AccountConstraint
Sourcepub const fn on(index: usize) -> Self
pub const fn on(index: usize) -> Self
Start building constraints for an account at the given index.
Sourcepub const fn executable(self) -> Self
pub const fn executable(self) -> Self
Require the account to be executable.
Sourcepub fn validate(&self, ctx: &ValidationContext<'_>) -> ProgramResult
pub fn validate(&self, ctx: &ValidationContext<'_>) -> ProgramResult
Validate all constraints against the context.