pub struct RingBuffer<'a, T: Pod + FixedLayout> { /* private fields */ }Expand description
Fixed-capacity circular buffer overlaid on a byte slice.
pushalways succeeds. When full, overwrites the oldest entry.- Use for event journals, audit logs, price history, etc.
- O(1) push, O(1) read by logical index.
Implementations
Sourceimpl<'a, T: Pod + FixedLayout> RingBuffer<'a, T>
impl<'a, T: Pod + FixedLayout> RingBuffer<'a, T>
Sourcepub fn from_bytes(data: &'a mut [u8]) -> Result<Self, ProgramError>
pub fn from_bytes(data: &'a mut [u8]) -> Result<Self, ProgramError>
Overlay a RingBuffer on a mutable byte slice.
Sourcepub fn count(&self) -> usize
pub fn count(&self) -> usize
Current number of elements (may be less than capacity if not yet full).
Sourcepub fn push(&mut self, value: T) -> Result<(), ProgramError>
pub fn push(&mut self, value: T) -> Result<(), ProgramError>
Push an element. If the buffer is full, overwrites the oldest entry.
Sourcepub fn get(&self, logical_index: usize) -> Result<T, ProgramError>
pub fn get(&self, logical_index: usize) -> Result<T, ProgramError>
Read the element at logical index (0 = oldest still in buffer).
Sourcepub fn latest(&self) -> Result<T, ProgramError>
pub fn latest(&self) -> Result<T, ProgramError>
Read the most recently pushed element.
Sourcepub fn oldest(&self) -> Result<T, ProgramError>
pub fn oldest(&self) -> Result<T, ProgramError>
Read the oldest element.
Sourcepub const fn required_bytes(capacity: usize) -> usize
pub const fn required_bytes(capacity: usize) -> usize
Compute the byte size needed for a RingBuffer with the given capacity.